<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Volba aplikace</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Vybrat aplikaci pro:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Aplikace zpracovávající JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Nový podbod</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="191"/>
        <location filename="../applicationchooser.cpp" line="217"/>
        <source>Other applications</source>
        <translation>Ostatní aplikace</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="147"/>
        <source>Web browsers</source>
        <translation>Prohlížeče webových stránek</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="152"/>
        <source>Email clients</source>
        <translation>Klienti elektronické pošty</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="157"/>
        <source>File managers</source>
        <translation>Správci souborů</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="193"/>
        <location filename="../applicationchooser.cpp" line="219"/>
        <source>Other applications that handle %1</source>
        <translation>Další aplikace spravující %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="194"/>
        <location filename="../applicationchooser.cpp" line="220"/>
        <source>Applications that handle %1</source>
        <translation>Aplikace zpracovávající %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="305"/>
        <source>No applications found</source>
        <translation>Nenalezeny žádné aplikace</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="310"/>
        <source>No more applications found</source>
        <translation>Nebyly nalezeny žádné další aplikace</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="271"/>
        <location filename="../mimetypeviewer.cpp" line="290"/>
        <location filename="../mimetypeviewer.cpp" line="309"/>
        <source>Change...</source>
        <translation>Změnit…</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="275"/>
        <location filename="../mimetypeviewer.cpp" line="294"/>
        <location filename="../mimetypeviewer.cpp" line="313"/>
        <location filename="../mimetypeviewer.cpp" line="327"/>
        <location filename="../mimetypeviewer.cpp" line="388"/>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="276"/>
        <location filename="../mimetypeviewer.cpp" line="295"/>
        <location filename="../mimetypeviewer.cpp" line="314"/>
        <source>Choose...</source>
        <translation>Vybrat…</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="384"/>
        <source>&amp;Change...</source>
        <translation>&amp;Změnit…</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="389"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Zvolit…</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Přiřazení souborů</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="30"/>
        <source>Associations</source>
        <translation>Přiřazení</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="206"/>
        <source>Default application</source>
        <translation>Výchozí aplikace</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="271"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Zvolit…</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="305"/>
        <source>Default Applications</source>
        <translation>Výchozí aplikace</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="347"/>
        <source>Web Browser</source>
        <translation>Webový prohlížeč</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="412"/>
        <location filename="../mimetypeviewer.ui" line="487"/>
        <location filename="../mimetypeviewer.ui" line="562"/>
        <source>Choose...</source>
        <translation>Vybrat…</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="422"/>
        <source>Email Client</source>
        <translation>Klient elektronické pošty</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="497"/>
        <source>File Manager</source>
        <translation>Správce souborů</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="255"/>
        <location filename="../mimetypeviewer.ui" line="396"/>
        <location filename="../mimetypeviewer.ui" line="471"/>
        <location filename="../mimetypeviewer.ui" line="546"/>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="187"/>
        <source>Patterns</source>
        <translation>Vzory</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="193"/>
        <source>*.txt *.xml</source>
        <translation>*.txt *.xml</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="146"/>
        <source>MIME type</source>
        <translation>MIME typ</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="164"/>
        <location filename="../mimetypeviewer.ui" line="248"/>
        <location filename="../mimetypeviewer.ui" line="389"/>
        <location filename="../mimetypeviewer.ui" line="464"/>
        <location filename="../mimetypeviewer.ui" line="539"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="171"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
</context>
</TS>
